@@ -10,7 +10,7 @@ class ElastalertWebhook(WebhookBase):
 
         try:
             #for any missing key in payload, default value set to 'N/A'
-            print("using alerta-elastalert version: 0.0.15")
+            print("using alerta-elastalert version: 0.0.17")
             print("payload: "+str(payload))
             rawData = "data="+str(payload)
             resource = payload.get('queryKey','N/A')
@@ -20,11 +20,11 @@ class ElastalertWebhook(WebhookBase):
             #if event key present in payload, retrieve other nested key values
             if(res!="N/A"):
                 event = res.get('eventName','N/A')
-                severity =res.get('severity','N/A').lower()
+                severity =res.get('severity','unknown').lower()
                 text = res.get('message','N/A')
             else:
                 event = "N/A"
-                severity = "N/A"
+                severity = "unknown"
                 text = "N/A"
             tags = []
             attributes = {}
